@@ -45,8 +45,13 @@ class InMemoryLimiter(Limiter):
         :return: None
         :raise ConfigurationError: if storage is incorrectly configured
         """
-        self._storage_uri = storage_uri
-        self._key_prefix = key_prefix
+        # Specifically check for None here to avoid overriding any existing values
+        # which may have been set in the constructor
+        if storage_uri:
+            self._storage_uri = storage_uri
+        if key_prefix:
+            self._key_prefix = key_prefix
+
         super().init_app(app=app)
         self._check_storage()
 
@@ -56,6 +61,6 @@ class InMemoryLimiter(Limiter):
         :return: None
         :raise ConfigurationError: if storage is incorrectly configured
         """
-        if not self._storage.check() or self._storage_uri is None:
+        if not self._storage.check():
             self.logger.critical(f"Invalid storage configuration: {self._storage_uri}")
             raise ConfigurationError("Invalid storage configuration")
